ManageNoteSharesError

Struct ManageNoteSharesError 

pub struct ManageNoteSharesError {
    pub identity_i_d: Option<IdentityID>,
    pub user_i_d: Option<UserID>,
    pub user_exception: Option<EDAMUserException>,
    pub not_found_exception: Option<EDAMNotFoundException>,
}
Captures errors that occur during a call to manageNoteShares. That function can be run best-effort, meaning that some change requests can be applied while others fail. Note that some errors such as system exceptions may still cause the entire call to fail.

Only one of the two ID fields will be set on a given error.

Only one of the two exception fields will be set on a given error.

identityID
The identity ID of an outstanding invitation that was not updated due to the error.
userID
The user ID of an existing membership that was not updated due to the error.
userException
If the error is represented as an EDAMUserException that would have otherwise been thrown without best-effort execution.
notFoundException
If the error is represented as an EDAMNotFoundException that would have otherwise been thrown without best-effort execution. The identifier field of the exception will be either "Identity.id" or "User.id", indicating that no existing share could be found for the specified recipient.

Fields

identity_i_d: Option<IdentityID>user_i_d: Option<UserID>user_exception: Option<EDAMUserException>not_found_exception: Option<EDAMNotFoundException>

Implementations

Source

impl ManageNoteSharesError

pub fn new<F1, F2, F3, F4>( identity_i_d: F1, user_i_d: F2, user_exception: F3, not_found_exception: F4, ) -> ManageNoteSharesError