pub struct ManageNotebookSharesResult {
pub errors: Option<Vec<ManageNotebookSharesError>>,
}Expand description
The return value of a call to the manageNotebookShares method.
- errors
- If the method completed without throwing exceptions, some errors might still have occurred, and in that case, this field will contain the list of those errors the occurred.
Fields
errors: Option<Vec<ManageNotebookSharesError>>Implementations
pub fn new<F1>(errors: F1) -> ManageNotebookSharesResult