pub struct NotebookShareTemplate {
pub notebook_guid: Option<Guid>,
pub recipient_contacts: Option<Vec<Contact>>,
pub privilege: Option<SharedNotebookPrivilegeLevel>,
pub recipient_thread_id: Option<MessageThreadID>,
}Expand description
A structure used to share a notebook with one or more recipients at a given privilege.
- notebookGuid
- The GUID of the notebook.
- recipientThreadId
- The recipients of the notebook share specified as a messaging thread ID. If you have an existing messaging thread to share the note with, specify its ID here instead of recipientContacts in order to properly support defunct identities. The sharer must be a participant of the thread. Either this field or recipientContacts must be set.
- recipientContacts
- The recipients of the notebook share specified as a list of contacts. This should only be set if the sharing takes place before the thread is created. Use recipientThreadId instead when sharing with an existing thread. Either this field or recipientThreadId must be set.
- privilege
- The privilege level to be granted.
Fields
notebook_guid: Option<Guid>recipient_contacts: Option<Vec<Contact>>privilege: Option<SharedNotebookPrivilegeLevel>recipient_thread_id: Option<MessageThreadID>Implementations