NotebookDescriptor

Struct NotebookDescriptor 

pub struct NotebookDescriptor {
    pub guid: Option<Guid>,
    pub notebook_display_name: Option<String>,
    pub contact_name: Option<String>,
    pub has_shared_notebook: Option<bool>,
    pub joined_user_count: Option<i32>,
}
A structure that describes a notebook or a user’s relationship with a notebook. NotebookDescriptor is expected to remain a lighter-weight structure when compared to Notebook.

guid
The unique identifier of the notebook.
notebookDisplayName
A sequence of characters representing the name of the notebook.
contactName
The User.name value of the notebook's "contact".
hasSharedNotebook
Whether a SharedNotebook record exists between the calling user and this notebook.
joinedUserCount
The number of users who have joined this notebook.

Fields

guid: Option<Guid>notebook_display_name: Option<String>contact_name: Option<String>has_shared_notebook: Option<bool>joined_user_count: Option<i32>

Implementations

Source

impl NotebookDescriptor

pub fn new<F1, F2, F3, F4, F5>( guid: F1, notebook_display_name: F2, contact_name: F3, has_shared_notebook: F4, joined_user_count: F5, ) -> NotebookDescriptor
where F1: Into<Option<Guid>>, F2: Into<Option<String>>, F3: Into<Option<String>>, F4: Into<Option<bool>>, F5: Into<Option<i32>>,