SavedSearchScope

Struct SavedSearchScope 

pub struct SavedSearchScope {
    pub include_account: Option<bool>,
    pub include_personal_linked_notebooks: Option<bool>,
    pub include_business_linked_notebooks: Option<bool>,
}
A structure defining the scope of a SavedSearch.

includeAccount
The search should include notes from the account that contains the SavedSearch.
includePersonalLinkedNotebooks
The search should include notes within those shared notebooks that the user has joined that are NOT business notebooks.
includeBusinessLinkedNotebooks
The search should include notes within those shared notebooks that the user has joined that are business notebooks in the business that the user is currently a member of.

Fields

include_account: Option<bool>include_personal_linked_notebooks: Option<bool>include_business_linked_notebooks: Option<bool>

Implementations

Source

impl SavedSearchScope

pub fn new<F1, F2, F3>( include_account: F1, include_personal_linked_notebooks: F2, include_business_linked_notebooks: F3, ) -> SavedSearchScope
where F1: Into<Option<bool>>, F2: Into<Option<bool>>, F3: Into<Option<bool>>,