PublicUserInfo

Struct PublicUserInfo 

pub struct PublicUserInfo {
    pub user_id: UserID,
    pub username: Option<String>,
    pub note_store_url: Option<String>,
    pub web_api_url_prefix: Option<String>,
    pub service_level: Option<ServiceLevel>,
}
This structure is used to provide publicly-available user information about a particular account.

userId:
The unique numeric user identifier for the user account.
serviceLevel:
The service level of the account.
noteStoreUrl:
This field will contain the full URL that clients should use to make NoteStore requests to the server shard that contains that user's data. I.e. this is the URL that should be used to create the Thrift HTTP client transport to send messages to the NoteStore service for the account.
webApiUrlPrefix:
This field will contain the initial part of the URLs that should be used to make requests to Evernote's thin client "web API", which provide optimized operations for clients that aren't capable of manipulating the full contents of accounts via the full Thrift data model. Clients should concatenate the relative path for the various servlets onto the end of this string to construct the full URL, as documented on our developer web site.

Fields

user_id: UserIDusername: Option<String>note_store_url: Option<String>web_api_url_prefix: Option<String>service_level: Option<ServiceLevel>

Implementations

Source

impl PublicUserInfo

pub fn new<F4, F5, F6, F7>( user_id: UserID, username: F4, note_store_url: F5, web_api_url_prefix: F6, service_level: F7, ) -> PublicUserInfo