pub struct NoteCollectionCounts {
pub notebook_counts: Option<BTreeMap<Guid, i32>>,
pub tag_counts: Option<BTreeMap<Guid, i32>>,
pub trash_count: Option<i32>,
}Expand description
A data structure representing the number of notes for each notebook and tag with a non-zero set of applicable notes.
- notebookCounts
- A mapping from the Notebook GUID to the number of notes (from some selection) that are in the corresponding notebook.
- tagCounts
- A mapping from the Tag GUID to the number of notes (from some selection) that have the corresponding tag.
- trashCount
- If this is set, then this is the number of notes that are in the trash. If this is not set, then the number of notes in the trash hasn't been reported. (I.e. if there are no notes in the trash, this will be set to 0.)
Fields
notebook_counts: Option<BTreeMap<Guid, i32>>tag_counts: Option<BTreeMap<Guid, i32>>trash_count: Option<i32>Implementations