pub struct BusinessUserAttributes {
pub title: Option<String>,
pub location: Option<String>,
pub department: Option<String>,
pub mobile_phone: Option<String>,
pub linked_in_profile_url: Option<String>,
pub work_phone: Option<String>,
pub company_start_date: Option<Timestamp>,
}Expand description
A structure holding the optional attributes associated with users in a business.
- title
- Free form text of this user's title in the business
- location
- City, State (for US) or City / Province for other countries
- department
- Free form text of the department this user belongs to.
- mobilePhone
- User's mobile phone number. Stored as plain text without any formatting.
- linkedInProfileUrl
- URL to user's public LinkedIn profile page. This should only contain the portion relative to the base LinkedIn URL. For example: "/pub/john-smith/".
- workPhone
- User's work phone number. Stored as plain text without any formatting.
- companyStartDate
- The date on which the user started working at their company.
Fields
title: Option<String>location: Option<String>department: Option<String>mobile_phone: Option<String>linked_in_profile_url: Option<String>work_phone: Option<String>company_start_date: Option<Timestamp>Implementations
Sourceimpl BusinessUserAttributes
impl BusinessUserAttributes
pub fn new<F1, F2, F3, F4, F5, F6, F7>( title: F1, location: F2, department: F3, mobile_phone: F4, linked_in_profile_url: F5, work_phone: F6, company_start_date: F7, ) -> BusinessUserAttributes