pub struct SavedSearchScope {
pub include_account: Option<bool>,
pub include_personal_linked_notebooks: Option<bool>,
pub include_business_linked_notebooks: Option<bool>,
}Expand description
A structure defining the scope of a SavedSearch.
- includeAccount
- The search should include notes from the account that contains the SavedSearch.
- includePersonalLinkedNotebooks
- The search should include notes within those shared notebooks that the user has joined that are NOT business notebooks.
- includeBusinessLinkedNotebooks
- The search should include notes within those shared notebooks that the user has joined that are business notebooks in the business that the user is currently a member of.
Fields
include_account: Option<bool>include_personal_linked_notebooks: Option<bool>include_business_linked_notebooks: Option<bool>Implementations